@@ -33,11 +33,11 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::FieldMasks;
-use Google::Ads::GoogleAds::V4::Resources::MerchantCenterLink;
-use Google::Ads::GoogleAds::V4::Enums::MerchantCenterLinkStatusEnum
+use Google::Ads::GoogleAds::V5::Resources::MerchantCenterLink;
+use Google::Ads::GoogleAds::V5::Enums::MerchantCenterLinkStatusEnum
   qw(ENABLED PENDING);
 use
-  Google::Ads::GoogleAds::V4::Services::MerchantCenterLinkService::MerchantCenterLinkOperation;
+  Google::Ads::GoogleAds::V5::Services::MerchantCenterLinkService::MerchantCenterLinkOperation;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -100,7 +100,7 @@ sub update_merchant_center_link_status {
   # Create an updated MerchantCenterLink object derived from the original, but
   # with the specified status.
   my $merchant_center_link_to_update =
-    Google::Ads::GoogleAds::V4::Resources::MerchantCenterLink->new({
+    Google::Ads::GoogleAds::V5::Resources::MerchantCenterLink->new({
       resourceName => $merchant_center_link->{resourceName},
       status       => $new_merchant_center_link_status
     });
@@ -109,7 +109,7 @@ sub update_merchant_center_link_status {
   # FieldMasks utility to derive the update mask. This mask tells the Google Ads
   # API which attributes of the Merchant Center link you want to change.
   my $merchant_center_link_operation =
-    Google::Ads::GoogleAds::V4::Services::MerchantCenterLinkService::MerchantCenterLinkOperation
+    Google::Ads::GoogleAds::V5::Services::MerchantCenterLinkService::MerchantCenterLinkOperation
     ->new({
       update     => $merchant_center_link_to_update,
       updateMask => all_set_fields_of($merchant_center_link_to_update)});
@@ -140,7 +140,7 @@ $api_client->set_die_on_faults(1);
 # Parameters passed on the command line will override any parameters set in code.
 GetOptions(
   "customer_id=s"                => \$customer_id,
-  "merchant_center_account_id=i" => \$merchant_center_account_id,
+  "merchant_center_account_id=i" => \$merchant_center_account_id
 );
 
 # Print the help message if the parameters are not initialized in the code nor
