@@ -21,8 +21,8 @@
 # IMPORTANT: The AssetService requires you to reuse what you've uploaded previously.
 # Therefore, you cannot create an image asset with the exactly same bytes. In
 # case you want to run this example more than once, note down the created assets'
-# resource names and specify them as command-line arguments for marketing and
-# square marketing images.
+# IDs and specify them as command-line arguments for marketing and square marketing
+# images.
 #
 # Alternatively, you can modify the image URLs' constants directly to use other
 # images.
@@ -36,30 +36,31 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::MediaUtils;
-use Google::Ads::GoogleAds::V4::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V4::Resources::Campaign;
-use Google::Ads::GoogleAds::V4::Resources::AdGroup;
-use Google::Ads::GoogleAds::V4::Resources::AdGroupAd;
-use Google::Ads::GoogleAds::V4::Resources::Ad;
-use Google::Ads::GoogleAds::V4::Resources::Asset;
-use Google::Ads::GoogleAds::V4::Common::TargetCpa;
-use Google::Ads::GoogleAds::V4::Common::ResponsiveDisplayAdInfo;
-use Google::Ads::GoogleAds::V4::Common::AdTextAsset;
-use Google::Ads::GoogleAds::V4::Common::AdImageAsset;
-use Google::Ads::GoogleAds::V4::Common::ImageAsset;
-use Google::Ads::GoogleAds::V4::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
-use Google::Ads::GoogleAds::V4::Enums::AdvertisingChannelTypeEnum qw(DISPLAY);
-use Google::Ads::GoogleAds::V4::Enums::AdvertisingChannelSubTypeEnum
+use Google::Ads::GoogleAds::V5::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V5::Resources::Campaign;
+use Google::Ads::GoogleAds::V5::Resources::AdGroup;
+use Google::Ads::GoogleAds::V5::Resources::AdGroupAd;
+use Google::Ads::GoogleAds::V5::Resources::Ad;
+use Google::Ads::GoogleAds::V5::Resources::Asset;
+use Google::Ads::GoogleAds::V5::Common::TargetCpa;
+use Google::Ads::GoogleAds::V5::Common::ResponsiveDisplayAdInfo;
+use Google::Ads::GoogleAds::V5::Common::AdTextAsset;
+use Google::Ads::GoogleAds::V5::Common::AdImageAsset;
+use Google::Ads::GoogleAds::V5::Common::ImageAsset;
+use Google::Ads::GoogleAds::V5::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
+use Google::Ads::GoogleAds::V5::Enums::AdvertisingChannelTypeEnum qw(DISPLAY);
+use Google::Ads::GoogleAds::V5::Enums::AdvertisingChannelSubTypeEnum
   qw(DISPLAY_SMART_CAMPAIGN);
-use Google::Ads::GoogleAds::V4::Enums::AdGroupStatusEnum;
-use Google::Ads::GoogleAds::V4::Enums::AdGroupAdStatusEnum;
-use Google::Ads::GoogleAds::V4::Enums::AssetTypeEnum qw(IMAGE);
+use Google::Ads::GoogleAds::V5::Enums::AdGroupStatusEnum;
+use Google::Ads::GoogleAds::V5::Enums::AdGroupAdStatusEnum;
+use Google::Ads::GoogleAds::V5::Enums::AssetTypeEnum qw(IMAGE);
 use
-  Google::Ads::GoogleAds::V4::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V4::Services::CampaignService::CampaignOperation;
-use Google::Ads::GoogleAds::V4::Services::AdGroupService::AdGroupOperation;
-use Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation;
-use Google::Ads::GoogleAds::V4::Services::AssetService::AssetOperation;
+  Google::Ads::GoogleAds::V5::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V5::Services::CampaignService::CampaignOperation;
+use Google::Ads::GoogleAds::V5::Services::AdGroupService::AdGroupOperation;
+use Google::Ads::GoogleAds::V5::Services::AdGroupAdService::AdGroupAdOperation;
+use Google::Ads::GoogleAds::V5::Services::AssetService::AssetOperation;
+use Google::Ads::GoogleAds::V5::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -80,18 +81,16 @@ use constant SQUARE_MARKETING_IMAGE_URL => "https://goo.gl/mtt54n";
 #
 # Running the example with -h will print the command line usage.
 my $customer_id = "INSERT_CUSTOMER_ID_HERE";
-# Optional: Specify the marketing image asset resource name and square marketing
-# image asset resource name below to be used to create a responsive display ad.
-# If none is specified, this example will create a new image assets.
-my $marketing_image_asset_resource_name        = undef;
-my $square_marketing_image_asset_resource_name = undef;
+# Optional: Specify the marketing image asset ID and square marketing image asset
+# ID below to be used to create a responsive display ad. If none is specified,
+# this example will create a new image assets.
+my $marketing_image_asset_id        = undef;
+my $square_marketing_image_asset_id = undef;
 
 sub add_smart_display_ad {
-  my (
-    $api_client, $customer_id,
-    $marketing_image_asset_resource_name,
-    $square_marketing_image_asset_resource_name
-  ) = @_;
+  my ($api_client, $customer_id, $marketing_image_asset_id,
+    $square_marketing_image_asset_id)
+    = @_;
 
   my $budget_resource_name = create_campaign_budget($api_client, $customer_id);
 
@@ -102,11 +101,9 @@ sub add_smart_display_ad {
   my $ad_group_resource_name =
     create_ad_group($api_client, $customer_id, $campaign_resource_name);
 
-  create_responsive_display_ad(
-    $api_client, $customer_id, $ad_group_resource_name,
-    $marketing_image_asset_resource_name,
-    $square_marketing_image_asset_resource_name
-  );
+  create_responsive_display_ad($api_client, $customer_id,
+    $ad_group_resource_name, $marketing_image_asset_id,
+    $square_marketing_image_asset_id);
 
   return 1;
 }
@@ -117,7 +114,7 @@ sub create_campaign_budget {
 
   # Create a campaign budget.
   my $campaign_budget =
-    Google::Ads::GoogleAds::V4::Resources::CampaignBudget->new({
+    Google::Ads::GoogleAds::V5::Resources::CampaignBudget->new({
       name           => "Interplanetary Cruise Budget #" . uniqid(),
       deliveryMethod => STANDARD,
       amountMicros   => 5000000
@@ -125,7 +122,7 @@ sub create_campaign_budget {
 
   # Create a campaign budget operation.
   my $campaign_budget_operation =
-    Google::Ads::GoogleAds::V4::Services::CampaignBudgetService::CampaignBudgetOperation
+    Google::Ads::GoogleAds::V5::Services::CampaignBudgetService::CampaignBudgetOperation
     ->new({
       create => $campaign_budget
     });
@@ -147,7 +144,7 @@ sub create_campaign_budget {
 sub create_smart_display_campaign {
   my ($api_client, $customer_id, $campaign_budget_resource_name) = @_;
 
-  my $campaign = Google::Ads::GoogleAds::V4::Resources::Campaign->new({
+  my $campaign = Google::Ads::GoogleAds::V5::Resources::Campaign->new({
       name => "Smart Display Campaign #" . uniqid(),
       # Smart Display campaign requires the advertising_channel_type as 'DISPLAY'.
       advertisingChannelType => DISPLAY,
@@ -155,7 +152,7 @@ sub create_smart_display_campaign {
       # 'DISPLAY_SMART_CAMPAIGN'.
       advertisingChannelSubType => DISPLAY_SMART_CAMPAIGN,
       # Smart Display campaign requires the TargetCpa bidding strategy.
-      targetCpa => Google::Ads::GoogleAds::V4::Common::TargetCpa->new({
+      targetCpa => Google::Ads::GoogleAds::V5::Common::TargetCpa->new({
           targetCpaMicros => 5000000
         }
       ),
@@ -168,7 +165,7 @@ sub create_smart_display_campaign {
 
   # Create a campaign operation.
   my $campaign_operation =
-    Google::Ads::GoogleAds::V4::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V5::Services::CampaignService::CampaignOperation->
     new({
       create => $campaign
     });
@@ -192,15 +189,15 @@ sub create_ad_group {
   my ($api_client, $customer_id, $campaign_resource_name) = @_;
 
   # Construct an ad group and set its type.
-  my $ad_group = Google::Ads::GoogleAds::V4::Resources::AdGroup->new({
+  my $ad_group = Google::Ads::GoogleAds::V5::Resources::AdGroup->new({
     name     => "Earth to Mars Cruises #" . uniqid(),
     campaign => $campaign_resource_name,
-    status   => Google::Ads::GoogleAds::V4::Enums::AdGroupStatusEnum::PAUSED
+    status   => Google::Ads::GoogleAds::V5::Enums::AdGroupStatusEnum::PAUSED
   });
 
   # Create an ad group operation.
   my $ad_group_operation =
-    Google::Ads::GoogleAds::V4::Services::AdGroupService::AdGroupOperation->new(
+    Google::Ads::GoogleAds::V5::Services::AdGroupService::AdGroupOperation->new(
     {
       create => $ad_group
     });
@@ -221,39 +218,41 @@ sub create_ad_group {
 # Creates a responsive display ad, which is a recommended ad type for Smart
 # Display campaigns.
 sub create_responsive_display_ad {
-  my (
-    $api_client, $customer_id, $ad_group_resource_name,
-    $marketing_image_asset_resource_name,
-    $square_marketing_image_asset_resource_name
-  ) = @_;
+  my ($api_client, $customer_id, $ad_group_resource_name,
+    $marketing_image_asset_id, $square_marketing_image_asset_id)
+    = @_;
 
   # Create a new image asset for marketing image and square marketing image if
-  # there are no assets' resource names specified.
-  $marketing_image_asset_resource_name =
-    create_image_asset($api_client, $customer_id, MARKETING_IMAGE_URL,
-    "Marketing Image")
-    if not $marketing_image_asset_resource_name;
+  # there are no assets' IDs specified.
+  my $marketing_image_asset_resource_name =
+    defined $marketing_image_asset_id
+    ? Google::Ads::GoogleAds::V5::Utils::ResourceNames::asset($customer_id,
+    $marketing_image_asset_id)
+    : create_image_asset($api_client, $customer_id, MARKETING_IMAGE_URL,
+    "Marketing Image");
 
-  $square_marketing_image_asset_resource_name =
-    create_image_asset($api_client, $customer_id, SQUARE_MARKETING_IMAGE_URL,
-    "Square Marketing Image")
-    if not $square_marketing_image_asset_resource_name;
+  my $square_marketing_image_asset_resource_name =
+    defined $square_marketing_image_asset_id
+    ? Google::Ads::GoogleAds::V5::Utils::ResourceNames::asset($customer_id,
+    $square_marketing_image_asset_id)
+    : create_image_asset($api_client, $customer_id, SQUARE_MARKETING_IMAGE_URL,
+    "Square Marketing Image");
 
   # Create a responsive display ad info.
   my $responsive_display_ad_info =
-    Google::Ads::GoogleAds::V4::Common::ResponsiveDisplayAdInfo->new({
+    Google::Ads::GoogleAds::V5::Common::ResponsiveDisplayAdInfo->new({
       # Set some basic required information for the responsive display ad.
       headlines => [
-        Google::Ads::GoogleAds::V4::Common::AdTextAsset->new({
+        Google::Ads::GoogleAds::V5::Common::AdTextAsset->new({
             text => "Travel"
           })
       ],
-      longHeadline => Google::Ads::GoogleAds::V4::Common::AdTextAsset->new({
+      longHeadline => Google::Ads::GoogleAds::V5::Common::AdTextAsset->new({
           text => "Travel the World"
         }
       ),
       descriptions => [
-        Google::Ads::GoogleAds::V4::Common::AdTextAsset->new({
+        Google::Ads::GoogleAds::V5::Common::AdTextAsset->new({
             text => "Take to the air!"
           })
       ],
@@ -261,12 +260,12 @@ sub create_responsive_display_ad {
       # Set the marketing image and square marketing image to the previously
       # created image assets.
       marketingImages => [
-        Google::Ads::GoogleAds::V4::Common::AdImageAsset->new({
+        Google::Ads::GoogleAds::V5::Common::AdImageAsset->new({
             asset => $marketing_image_asset_resource_name
           })
       ],
       squareMarketingImages => [
-        Google::Ads::GoogleAds::V4::Common::AdImageAsset->new({
+        Google::Ads::GoogleAds::V5::Common::AdImageAsset->new({
             asset => $square_marketing_image_asset_resource_name
           })
       ],
@@ -277,17 +276,17 @@ sub create_responsive_display_ad {
     });
 
   # Create an ad group ad with the created responsive display ad info.
-  my $ad_group_ad = Google::Ads::GoogleAds::V4::Resources::AdGroupAd->new({
+  my $ad_group_ad = Google::Ads::GoogleAds::V5::Resources::AdGroupAd->new({
       adGroup => $ad_group_resource_name,
-      status  => Google::Ads::GoogleAds::V4::Enums::AdGroupAdStatusEnum::PAUSED,
-      ad      => Google::Ads::GoogleAds::V4::Resources::Ad->new({
+      status  => Google::Ads::GoogleAds::V5::Enums::AdGroupAdStatusEnum::PAUSED,
+      ad      => Google::Ads::GoogleAds::V5::Resources::Ad->new({
           finalUrls           => ["https://www.example.com"],
           responsiveDisplayAd => $responsive_display_ad_info
         })});
 
   # Create an ad group ad operation.
   my $ad_group_ad_operation =
-    Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation
+    Google::Ads::GoogleAds::V5::Services::AdGroupAdService::AdGroupAdOperation
     ->new({
       create => $ad_group_ad
     });
@@ -308,15 +307,15 @@ sub create_image_asset {
   my ($api_client, $customer_id, $image_url, $image_name) = @_;
 
   # Create an asset.
-  my $asset = Google::Ads::GoogleAds::V4::Resources::Asset->new({
+  my $asset = Google::Ads::GoogleAds::V5::Resources::Asset->new({
       name       => $image_name,
       type       => IMAGE,
-      imageAsset => Google::Ads::GoogleAds::V4::Common::ImageAsset->new({
+      imageAsset => Google::Ads::GoogleAds::V5::Common::ImageAsset->new({
           data => get_base64_data_from_url($image_url)})});
 
   # Create an asset operation.
   my $asset_operation =
-    Google::Ads::GoogleAds::V4::Services::AssetService::AssetOperation->new({
+    Google::Ads::GoogleAds::V5::Services::AssetService::AssetOperation->new({
       create => $asset
     });
 
@@ -346,11 +345,9 @@ $api_client->set_die_on_faults(1);
 
 # Parameters passed on the command line will override any parameters set in code.
 GetOptions(
-  "customer_id=s" => \$customer_id,
-  "marketing_image_asset_resource_name=s" =>
-    \$marketing_image_asset_resource_name,
-  "square_marketing_image_asset_resource_name=s" =>
-    \$square_marketing_image_asset_resource_name
+  "customer_id=s"                  => \$customer_id,
+  "marketing_image_asset_id=i"     => \$marketing_image_asset_id,
+  "square_marketing_image_asset=i" => \$square_marketing_image_asset_id
 );
 
 # Print the help message if the parameters are not initialized in the code nor
@@ -358,12 +355,8 @@ GetOptions(
 pod2usage(2) if not check_params($customer_id);
 
 # Call the example.
-add_smart_display_ad(
-  $api_client,
-  $customer_id =~ s/-//gr,
-  $marketing_image_asset_resource_name,
-  $square_marketing_image_asset_resource_name
-);
+add_smart_display_ad($api_client, $customer_id =~ s/-//gr,
+  $marketing_image_asset_id, $square_marketing_image_asset_id);
 
 =pod
 
@@ -379,8 +372,8 @@ https://support.google.com/google-ads/answer/7020281.
 
 IMPORTANT: The AssetService requires you to reuse what you've uploaded previously.
 Therefore, you cannot create an image asset with the exactly same bytes. In case
-you want to run this example more than once, note down the created assets' resource
-names and specify them as command-line arguments for marketing and square marketing
+you want to run this example more than once, note down the created assets' IDs
+and specify them as command-line arguments for marketing and square marketing
 images.
 
 Alternatively, you can modify the image URLs' constants directly to use other images.
@@ -389,9 +382,9 @@ Alternatively, you can modify the image URLs' constants directly to use other im
 
 add_smart_display_ad.pl [options]
 
-    -help                                           Show the help message.
-    -customer_id                                    The Google Ads customer ID.
-    -marketing_image_asset_resource_name            [optional] The resource name of marketing image asset.
-    -square_marketing_image_asset_resource_name     [optional] The resource name of square marketing image asset.
+    -help                                Show the help message.
+    -customer_id                         The Google Ads customer ID.
+    -marketing_image_asset_id            [optional] The ID of marketing image asset.
+    -square_marketing_image_asset_id     [optional] The ID of square marketing image asset.
 
 =cut
