@@ -25,20 +25,20 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V4::Resources::BiddingStrategy;
-use Google::Ads::GoogleAds::V4::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V4::Resources::Campaign;
-use Google::Ads::GoogleAds::V4::Resources::NetworkSettings;
-use Google::Ads::GoogleAds::V4::Common::TargetSpend;
-use Google::Ads::GoogleAds::V4::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
-use Google::Ads::GoogleAds::V4::Enums::AdvertisingChannelTypeEnum qw(SEARCH);
-use Google::Ads::GoogleAds::V4::Enums::CampaignStatusEnum qw(PAUSED);
+use Google::Ads::GoogleAds::V5::Resources::BiddingStrategy;
+use Google::Ads::GoogleAds::V5::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V5::Resources::Campaign;
+use Google::Ads::GoogleAds::V5::Resources::NetworkSettings;
+use Google::Ads::GoogleAds::V5::Common::TargetSpend;
+use Google::Ads::GoogleAds::V5::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
+use Google::Ads::GoogleAds::V5::Enums::AdvertisingChannelTypeEnum qw(SEARCH);
+use Google::Ads::GoogleAds::V5::Enums::CampaignStatusEnum qw(PAUSED);
 use
-  Google::Ads::GoogleAds::V4::Services::BiddingStrategyService::BiddingStrategyOperation;
+  Google::Ads::GoogleAds::V5::Services::BiddingStrategyService::BiddingStrategyOperation;
 use
-  Google::Ads::GoogleAds::V4::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V4::Services::CampaignService::CampaignOperation;
-use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V5::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V5::Services::CampaignService::CampaignOperation;
+use Google::Ads::GoogleAds::V5::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -66,7 +66,7 @@ sub use_portfolio_bidding_strategy {
 
   my $campaign_budget_resource_name =
     $campaign_budget_id
-    ? Google::Ads::GoogleAds::V4::Utils::ResourceNames::campaign_budget(
+    ? Google::Ads::GoogleAds::V5::Utils::ResourceNames::campaign_budget(
     $customer_id, $campaign_budget_id)
     : create_shared_campaign_buget($api_client, $customer_id);
 
@@ -85,18 +85,17 @@ sub create_bidding_strategy {
 
   # Create a portfolio bidding strategy.
   my $portfolio_bidding_strategy =
-    Google::Ads::GoogleAds::V4::Resources::BiddingStrategy->new({
+    Google::Ads::GoogleAds::V5::Resources::BiddingStrategy->new({
       name        => "Maximize Clicks #" . uniqid(),
-      targetSpend => Google::Ads::GoogleAds::V4::Common::TargetSpend->new({
-          cpcBidCeilingMicros => 2000000,
-          targetSpendMicros   => 20000000
+      targetSpend => Google::Ads::GoogleAds::V5::Common::TargetSpend->new({
+          cpcBidCeilingMicros => 2000000
         }
       ),
     });
 
   # Create a bidding strategy operation.
   my $bidding_strategy_operation =
-    Google::Ads::GoogleAds::V4::Services::BiddingStrategyService::BiddingStrategyOperation
+    Google::Ads::GoogleAds::V5::Services::BiddingStrategyService::BiddingStrategyOperation
     ->new({
       create => $portfolio_bidding_strategy
     });
@@ -122,7 +121,7 @@ sub create_shared_campaign_buget {
 
   # Create a shared budget.
   my $campaign_budget =
-    Google::Ads::GoogleAds::V4::Resources::CampaignBudget->new({
+    Google::Ads::GoogleAds::V5::Resources::CampaignBudget->new({
       name           => "Shared Interplanetary Budget #" . uniqid(),
       deliveryMethod => STANDARD,
       # Set the amount of budget.
@@ -133,7 +132,7 @@ sub create_shared_campaign_buget {
 
   # Create a campaign budget operation.
   my $campaign_budget_operation =
-    Google::Ads::GoogleAds::V4::Services::CampaignBudgetService::CampaignBudgetOperation
+    Google::Ads::GoogleAds::V5::Services::CampaignBudgetService::CampaignBudgetOperation
     ->new({create => $campaign_budget});
 
   # Add the campaign budget.
@@ -159,7 +158,7 @@ sub create_campaign_with_bidding_strategy {
   ) = @_;
 
   # Create a search campaign.
-  my $campaign = Google::Ads::GoogleAds::V4::Resources::Campaign->new({
+  my $campaign = Google::Ads::GoogleAds::V5::Resources::Campaign->new({
       name                   => "Interplanetary Cruise #" . uniqid(),
       advertisingChannelType => SEARCH,
       # Recommendation: Set the campaign to PAUSED when creating it to stop
@@ -168,7 +167,7 @@ sub create_campaign_with_bidding_strategy {
       status => PAUSED,
       # Configures the campaign network options.
       networkSettings =>
-        Google::Ads::GoogleAds::V4::Resources::NetworkSettings->new({
+        Google::Ads::GoogleAds::V5::Resources::NetworkSettings->new({
           targetGoogleSearch   => "true",
           targetSearchNetwork  => "true",
           targetContentNetwork => "true"
@@ -181,7 +180,7 @@ sub create_campaign_with_bidding_strategy {
 
   # Create a campaign operation.
   my $campaign_operation =
-    Google::Ads::GoogleAds::V4::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V5::Services::CampaignService::CampaignOperation->
     new({create => $campaign});
 
   # Add the campaign.
